/***************************************************************************//**
* \file CapSense_RegisterMap.h
* \version 5.0
*
* \brief
*   This file provides the definitions for the Component data structure register.
*
* \see CapSense v5.0 Datasheet
*
*//*****************************************************************************
* Copyright (2016-2017), Cypress Semiconductor Corporation.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is
* protected by and subject to worldwide patent protection (United States and
* foreign), United States copyright laws and international treaty provisions.
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable
* license to copy, use, modify, create derivative works of, and compile the
* Cypress Source Code and derivative works for the sole purpose of creating
* custom software in support of licensee product to be used only in conjunction
* with a Cypress integrated circuit as specified in the applicable agreement.
* Any reproduction, modification, translation, compilation, or representation of
* this software except as specified above is prohibited without the express
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the
* materials described herein. Cypress does not assume any liability arising out
* of the application or use of any product or circuit described herein. Cypress
* does not authorize its products for use as critical components in life-support
* systems where a malfunction or failure may reasonably be expected to result in
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of
* such use and in doing so indemnifies Cypress against all charges. Use may be
* limited by and subject to the applicable Cypress software license agreement.
*******************************************************************************/

#if !defined(CY_SENSE_CapSense_REGISTER_MAP_H)
#define CY_SENSE_CapSense_REGISTER_MAP_H

#include <cytypes.h>
#include "CapSense_Configuration.h"
#include "CapSense_Structure.h"

/*****************************************************************************/
/* RAM Data structure register definitions                                   */
/*****************************************************************************/
#define CapSense_CONFIG_ID_VALUE                            (CapSense_dsRam.configId)
#define CapSense_CONFIG_ID_OFFSET                           (0u)
#define CapSense_CONFIG_ID_SIZE                             (2u)
#define CapSense_CONFIG_ID_PARAM_ID                         (0x87000000u)

#define CapSense_DEVICE_ID_VALUE                            (CapSense_dsRam.deviceId)
#define CapSense_DEVICE_ID_OFFSET                           (2u)
#define CapSense_DEVICE_ID_SIZE                             (2u)
#define CapSense_DEVICE_ID_PARAM_ID                         (0x8B000002u)

#define CapSense_HW_CLOCK_VALUE                             (CapSense_dsRam.hwClock)
#define CapSense_HW_CLOCK_OFFSET                            (4u)
#define CapSense_HW_CLOCK_SIZE                              (2u)
#define CapSense_HW_CLOCK_PARAM_ID                          (0x86000004u)

#define CapSense_TUNER_CMD_VALUE                            (CapSense_dsRam.tunerCmd)
#define CapSense_TUNER_CMD_OFFSET                           (6u)
#define CapSense_TUNER_CMD_SIZE                             (2u)
#define CapSense_TUNER_CMD_PARAM_ID                         (0xA1000006u)

#define CapSense_SCAN_COUNTER_VALUE                         (CapSense_dsRam.scanCounter)
#define CapSense_SCAN_COUNTER_OFFSET                        (8u)
#define CapSense_SCAN_COUNTER_SIZE                          (2u)
#define CapSense_SCAN_COUNTER_PARAM_ID                      (0x85000008u)

#define CapSense_STATUS_VALUE                               (CapSense_dsRam.status)
#define CapSense_STATUS_OFFSET                              (12u)
#define CapSense_STATUS_SIZE                                (4u)
#define CapSense_STATUS_PARAM_ID                            (0xCB00000Cu)

#define CapSense_WDGT_ENABLE0_VALUE                         (CapSense_dsRam.wdgtEnable[0u])
#define CapSense_WDGT_ENABLE0_OFFSET                        (16u)
#define CapSense_WDGT_ENABLE0_SIZE                          (4u)
#define CapSense_WDGT_ENABLE0_PARAM_ID                      (0xE6000010u)

#define CapSense_WDGT_WORKING0_VALUE                        (CapSense_dsRam.wdgtWorking[0u])
#define CapSense_WDGT_WORKING0_OFFSET                       (20u)
#define CapSense_WDGT_WORKING0_SIZE                         (4u)
#define CapSense_WDGT_WORKING0_PARAM_ID                     (0xCC000014u)

#define CapSense_WDGT_STATUS0_VALUE                         (CapSense_dsRam.wdgtStatus[0u])
#define CapSense_WDGT_STATUS0_OFFSET                        (24u)
#define CapSense_WDGT_STATUS0_SIZE                          (4u)
#define CapSense_WDGT_STATUS0_PARAM_ID                      (0xCF000018u)

#define CapSense_SNS_STATUS0_VALUE                          (CapSense_dsRam.snsStatus[0u])
#define CapSense_SNS_STATUS0_OFFSET                         (28u)
#define CapSense_SNS_STATUS0_SIZE                           (1u)
#define CapSense_SNS_STATUS0_PARAM_ID                       (0x4900001Cu)

#define CapSense_CSD0_CONFIG_VALUE                          (CapSense_dsRam.csd0Config)
#define CapSense_CSD0_CONFIG_OFFSET                         (30u)
#define CapSense_CSD0_CONFIG_SIZE                           (2u)
#define CapSense_CSD0_CONFIG_PARAM_ID                       (0xAB80001Eu)

#define CapSense_MOD_CSD_CLK_VALUE                          (CapSense_dsRam.modCsdClk)
#define CapSense_MOD_CSD_CLK_OFFSET                         (32u)
#define CapSense_MOD_CSD_CLK_SIZE                           (1u)
#define CapSense_MOD_CSD_CLK_PARAM_ID                       (0x63800020u)

#define CapSense_GLB_CRC_VALUE                              (CapSense_dsRam.glbCrc)
#define CapSense_GLB_CRC_OFFSET                             (34u)
#define CapSense_GLB_CRC_SIZE                               (2u)
#define CapSense_GLB_CRC_PARAM_ID                           (0x81000022u)

#define CapSense_CAPTEUR_CRC_VALUE                          (CapSense_dsRam.wdgtList.capteur.crc)
#define CapSense_CAPTEUR_CRC_OFFSET                         (36u)
#define CapSense_CAPTEUR_CRC_SIZE                           (2u)
#define CapSense_CAPTEUR_CRC_PARAM_ID                       (0x8C000024u)

#define CapSense_CAPTEUR_RESOLUTION_VALUE                   (CapSense_dsRam.wdgtList.capteur.resolution)
#define CapSense_CAPTEUR_RESOLUTION_OFFSET                  (38u)
#define CapSense_CAPTEUR_RESOLUTION_SIZE                    (2u)
#define CapSense_CAPTEUR_RESOLUTION_PARAM_ID                (0xA6800026u)

#define CapSense_CAPTEUR_FINGER_TH_VALUE                    (CapSense_dsRam.wdgtList.capteur.fingerTh)
#define CapSense_CAPTEUR_FINGER_TH_OFFSET                   (40u)
#define CapSense_CAPTEUR_FINGER_TH_SIZE                     (2u)
#define CapSense_CAPTEUR_FINGER_TH_PARAM_ID                 (0xA9800028u)

#define CapSense_CAPTEUR_NOISE_TH_VALUE                     (CapSense_dsRam.wdgtList.capteur.noiseTh)
#define CapSense_CAPTEUR_NOISE_TH_OFFSET                    (42u)
#define CapSense_CAPTEUR_NOISE_TH_SIZE                      (1u)
#define CapSense_CAPTEUR_NOISE_TH_PARAM_ID                  (0x6D80002Au)

#define CapSense_CAPTEUR_NNOISE_TH_VALUE                    (CapSense_dsRam.wdgtList.capteur.nNoiseTh)
#define CapSense_CAPTEUR_NNOISE_TH_OFFSET                   (43u)
#define CapSense_CAPTEUR_NNOISE_TH_SIZE                     (1u)
#define CapSense_CAPTEUR_NNOISE_TH_PARAM_ID                 (0x6B80002Bu)

#define CapSense_CAPTEUR_HYSTERESIS_VALUE                   (CapSense_dsRam.wdgtList.capteur.hysteresis)
#define CapSense_CAPTEUR_HYSTERESIS_OFFSET                  (44u)
#define CapSense_CAPTEUR_HYSTERESIS_SIZE                    (1u)
#define CapSense_CAPTEUR_HYSTERESIS_PARAM_ID                (0x6080002Cu)

#define CapSense_CAPTEUR_ON_DEBOUNCE_VALUE                  (CapSense_dsRam.wdgtList.capteur.onDebounce)
#define CapSense_CAPTEUR_ON_DEBOUNCE_OFFSET                 (45u)
#define CapSense_CAPTEUR_ON_DEBOUNCE_SIZE                   (1u)
#define CapSense_CAPTEUR_ON_DEBOUNCE_PARAM_ID               (0x6680002Du)

#define CapSense_CAPTEUR_LOW_BSLN_RST_VALUE                 (CapSense_dsRam.wdgtList.capteur.lowBslnRst)
#define CapSense_CAPTEUR_LOW_BSLN_RST_OFFSET                (46u)
#define CapSense_CAPTEUR_LOW_BSLN_RST_SIZE                  (1u)
#define CapSense_CAPTEUR_LOW_BSLN_RST_PARAM_ID              (0x6C80002Eu)

#define CapSense_CAPTEUR_IDAC_MOD0_VALUE                    (CapSense_dsRam.wdgtList.capteur.idacMod[0u])
#define CapSense_CAPTEUR_IDAC_MOD0_OFFSET                   (47u)
#define CapSense_CAPTEUR_IDAC_MOD0_SIZE                     (1u)
#define CapSense_CAPTEUR_IDAC_MOD0_PARAM_ID                 (0x4C00002Fu)

#define CapSense_CAPTEUR_SNS_CLK_VALUE                      (CapSense_dsRam.wdgtList.capteur.snsClk)
#define CapSense_CAPTEUR_SNS_CLK_OFFSET                     (48u)
#define CapSense_CAPTEUR_SNS_CLK_SIZE                       (2u)
#define CapSense_CAPTEUR_SNS_CLK_PARAM_ID                   (0xAE800030u)

#define CapSense_CAPTEUR_SNS_CLK_SOURCE_VALUE               (CapSense_dsRam.wdgtList.capteur.snsClkSource)
#define CapSense_CAPTEUR_SNS_CLK_SOURCE_OFFSET              (50u)
#define CapSense_CAPTEUR_SNS_CLK_SOURCE_SIZE                (1u)
#define CapSense_CAPTEUR_SNS_CLK_SOURCE_PARAM_ID            (0x41800032u)

#define CapSense_CAPTEUR_PROX_TOUCH_TH_VALUE                (CapSense_dsRam.wdgtList.capteur.proxTouchTh)
#define CapSense_CAPTEUR_PROX_TOUCH_TH_OFFSET               (52u)
#define CapSense_CAPTEUR_PROX_TOUCH_TH_SIZE                 (2u)
#define CapSense_CAPTEUR_PROX_TOUCH_TH_PARAM_ID             (0xA2000034u)

#define CapSense_CAPTEUR_SNS0_RAW0_VALUE                    (CapSense_dsRam.snsList.capteur[0u].raw[0u])
#define CapSense_CAPTEUR_SNS0_RAW0_OFFSET                   (54u)
#define CapSense_CAPTEUR_SNS0_RAW0_SIZE                     (2u)
#define CapSense_CAPTEUR_SNS0_RAW0_PARAM_ID                 (0x85000036u)

#define CapSense_CAPTEUR_SNS0_BSLN0_VALUE                   (CapSense_dsRam.snsList.capteur[0u].bsln[0u])
#define CapSense_CAPTEUR_SNS0_BSLN0_OFFSET                  (56u)
#define CapSense_CAPTEUR_SNS0_BSLN0_SIZE                    (2u)
#define CapSense_CAPTEUR_SNS0_BSLN0_PARAM_ID                (0x8A000038u)

#define CapSense_CAPTEUR_SNS0_BSLN_INV0_VALUE               (CapSense_dsRam.snsList.capteur[0u].bslnInv[0u])
#define CapSense_CAPTEUR_SNS0_BSLN_INV0_OFFSET              (58u)
#define CapSense_CAPTEUR_SNS0_BSLN_INV0_SIZE                (2u)
#define CapSense_CAPTEUR_SNS0_BSLN_INV0_PARAM_ID            (0x8600003Au)

#define CapSense_CAPTEUR_SNS0_BSLN_EXT0_VALUE               (CapSense_dsRam.snsList.capteur[0u].bslnExt[0u])
#define CapSense_CAPTEUR_SNS0_BSLN_EXT0_OFFSET              (60u)
#define CapSense_CAPTEUR_SNS0_BSLN_EXT0_SIZE                (1u)
#define CapSense_CAPTEUR_SNS0_BSLN_EXT0_PARAM_ID            (0x4300003Cu)

#define CapSense_CAPTEUR_SNS0_DIFF_VALUE                    (CapSense_dsRam.snsList.capteur[0u].diff)
#define CapSense_CAPTEUR_SNS0_DIFF_OFFSET                   (62u)
#define CapSense_CAPTEUR_SNS0_DIFF_SIZE                     (2u)
#define CapSense_CAPTEUR_SNS0_DIFF_PARAM_ID                 (0x8700003Eu)

#define CapSense_CAPTEUR_SNS0_NEG_BSLN_RST_CNT0_VALUE       (CapSense_dsRam.snsList.capteur[0u].negBslnRstCnt[0u])
#define CapSense_CAPTEUR_SNS0_NEG_BSLN_RST_CNT0_OFFSET      (64u)
#define CapSense_CAPTEUR_SNS0_NEG_BSLN_RST_CNT0_SIZE        (1u)
#define CapSense_CAPTEUR_SNS0_NEG_BSLN_RST_CNT0_PARAM_ID    (0x42000040u)

#define CapSense_CAPTEUR_SNS0_IDAC_COMP0_VALUE              (CapSense_dsRam.snsList.capteur[0u].idacComp[0u])
#define CapSense_CAPTEUR_SNS0_IDAC_COMP0_OFFSET             (65u)
#define CapSense_CAPTEUR_SNS0_IDAC_COMP0_SIZE               (1u)
#define CapSense_CAPTEUR_SNS0_IDAC_COMP0_PARAM_ID           (0x44000041u)

#define CapSense_TEST_RESULT_MASK_VALUE                     (CapSense_dsRam.selfTest.testResultMask)
#define CapSense_TEST_RESULT_MASK_OFFSET                    (68u)
#define CapSense_TEST_RESULT_MASK_SIZE                      (4u)
#define CapSense_TEST_RESULT_MASK_PARAM_ID                  (0xEF000044u)

#define CapSense_EXT_CAP0_VALUE                             (CapSense_dsRam.selfTest.extCap[0u])
#define CapSense_EXT_CAP0_OFFSET                            (72u)
#define CapSense_EXT_CAP0_SIZE                              (2u)
#define CapSense_EXT_CAP0_PARAM_ID                          (0xA3000048u)

#define CapSense_VDDA_VOLTAGE_VALUE                         (CapSense_dsRam.selfTest.vddaVoltage)
#define CapSense_VDDA_VOLTAGE_OFFSET                        (74u)
#define CapSense_VDDA_VOLTAGE_SIZE                          (2u)
#define CapSense_VDDA_VOLTAGE_PARAM_ID                      (0xAF00004Au)

#define CapSense_SHIELD_CAP_VALUE                           (CapSense_dsRam.selfTest.shieldCap)
#define CapSense_SHIELD_CAP_OFFSET                          (76u)
#define CapSense_SHIELD_CAP_SIZE                            (2u)
#define CapSense_SHIELD_CAP_PARAM_ID                        (0xA200004Cu)

#define CapSense_GLB_CRC_CALC_VALUE                         (CapSense_dsRam.selfTest.glbCrcCalc)
#define CapSense_GLB_CRC_CALC_OFFSET                        (78u)
#define CapSense_GLB_CRC_CALC_SIZE                          (2u)
#define CapSense_GLB_CRC_CALC_PARAM_ID                      (0xAE00004Eu)

#define CapSense_WDGT_CRC_CALC_VALUE                        (CapSense_dsRam.selfTest.wdgtCrcCalc)
#define CapSense_WDGT_CRC_CALC_OFFSET                       (80u)
#define CapSense_WDGT_CRC_CALC_SIZE                         (2u)
#define CapSense_WDGT_CRC_CALC_PARAM_ID                     (0xA4000050u)

#define CapSense_WDGT_CRC_ID_VALUE                          (CapSense_dsRam.selfTest.wdgtCrcId)
#define CapSense_WDGT_CRC_ID_OFFSET                         (82u)
#define CapSense_WDGT_CRC_ID_SIZE                           (1u)
#define CapSense_WDGT_CRC_ID_PARAM_ID                       (0x60000052u)

#define CapSense_INV_BSLN_WDGT_ID_VALUE                     (CapSense_dsRam.selfTest.invBslnWdgtId)
#define CapSense_INV_BSLN_WDGT_ID_OFFSET                    (83u)
#define CapSense_INV_BSLN_WDGT_ID_SIZE                      (1u)
#define CapSense_INV_BSLN_WDGT_ID_PARAM_ID                  (0x66000053u)

#define CapSense_INV_BSLN_SNS_ID_VALUE                      (CapSense_dsRam.selfTest.invBslnSnsId)
#define CapSense_INV_BSLN_SNS_ID_OFFSET                     (84u)
#define CapSense_INV_BSLN_SNS_ID_SIZE                       (1u)
#define CapSense_INV_BSLN_SNS_ID_PARAM_ID                   (0x6D000054u)

#define CapSense_SHORTED_WDGT_ID_VALUE                      (CapSense_dsRam.selfTest.shortedWdgtId)
#define CapSense_SHORTED_WDGT_ID_OFFSET                     (85u)
#define CapSense_SHORTED_WDGT_ID_SIZE                       (1u)
#define CapSense_SHORTED_WDGT_ID_PARAM_ID                   (0x6B000055u)

#define CapSense_SHORTED_SNS_ID_VALUE                       (CapSense_dsRam.selfTest.shortedSnsId)
#define CapSense_SHORTED_SNS_ID_OFFSET                      (86u)
#define CapSense_SHORTED_SNS_ID_SIZE                        (1u)
#define CapSense_SHORTED_SNS_ID_PARAM_ID                    (0x61000056u)

#define CapSense_P2P_WDGT_ID_VALUE                          (CapSense_dsRam.selfTest.p2pWdgtId)
#define CapSense_P2P_WDGT_ID_OFFSET                         (87u)
#define CapSense_P2P_WDGT_ID_SIZE                           (1u)
#define CapSense_P2P_WDGT_ID_PARAM_ID                       (0x67000057u)

#define CapSense_P2P_SNS_ID_VALUE                           (CapSense_dsRam.selfTest.p2pSnsId)
#define CapSense_P2P_SNS_ID_OFFSET                          (88u)
#define CapSense_P2P_SNS_ID_SIZE                            (1u)
#define CapSense_P2P_SNS_ID_PARAM_ID                        (0x6E000058u)

#define CapSense_CAPTEUR_SNS_CP0_VALUE                      (CapSense_dsRam.snsCp.capteur[0u])
#define CapSense_CAPTEUR_SNS_CP0_OFFSET                     (92u)
#define CapSense_CAPTEUR_SNS_CP0_SIZE                       (1u)
#define CapSense_CAPTEUR_SNS_CP0_PARAM_ID                   (0x6F00005Cu)

#define CapSense_SNR_TEST_WIDGET_ID_VALUE                   (CapSense_dsRam.snrTestWidgetId)
#define CapSense_SNR_TEST_WIDGET_ID_OFFSET                  (93u)
#define CapSense_SNR_TEST_WIDGET_ID_SIZE                    (1u)
#define CapSense_SNR_TEST_WIDGET_ID_PARAM_ID                (0x6900005Du)

#define CapSense_SNR_TEST_SENSOR_ID_VALUE                   (CapSense_dsRam.snrTestSensorId)
#define CapSense_SNR_TEST_SENSOR_ID_OFFSET                  (94u)
#define CapSense_SNR_TEST_SENSOR_ID_SIZE                    (1u)
#define CapSense_SNR_TEST_SENSOR_ID_PARAM_ID                (0x6300005Eu)

#define CapSense_SNR_TEST_SCAN_COUNTER_VALUE                (CapSense_dsRam.snrTestScanCounter)
#define CapSense_SNR_TEST_SCAN_COUNTER_OFFSET               (96u)
#define CapSense_SNR_TEST_SCAN_COUNTER_SIZE                 (2u)
#define CapSense_SNR_TEST_SCAN_COUNTER_PARAM_ID             (0x80000060u)

#define CapSense_SNR_TEST_RAW_COUNT0_VALUE                  (CapSense_dsRam.snrTestRawCount[0u])
#define CapSense_SNR_TEST_RAW_COUNT0_OFFSET                 (98u)
#define CapSense_SNR_TEST_RAW_COUNT0_SIZE                   (2u)
#define CapSense_SNR_TEST_RAW_COUNT0_PARAM_ID               (0x8C000062u)


/*****************************************************************************/
/* Flash Data structure register definitions                                 */
/*****************************************************************************/
#define CapSense_CAPTEUR_PTR2SNS_FLASH_VALUE                (CapSense_dsFlash.wdgtArray[0].ptr2SnsFlash)
#define CapSense_CAPTEUR_PTR2SNS_FLASH_OFFSET               (0u)
#define CapSense_CAPTEUR_PTR2SNS_FLASH_SIZE                 (4u)
#define CapSense_CAPTEUR_PTR2SNS_FLASH_PARAM_ID             (0xD1000000u)

#define CapSense_CAPTEUR_PTR2WD_RAM_VALUE                   (CapSense_dsFlash.wdgtArray[0].ptr2WdgtRam)
#define CapSense_CAPTEUR_PTR2WD_RAM_OFFSET                  (4u)
#define CapSense_CAPTEUR_PTR2WD_RAM_SIZE                    (4u)
#define CapSense_CAPTEUR_PTR2WD_RAM_PARAM_ID                (0xD0000004u)

#define CapSense_CAPTEUR_PTR2SNS_RAM_VALUE                  (CapSense_dsFlash.wdgtArray[0].ptr2SnsRam)
#define CapSense_CAPTEUR_PTR2SNS_RAM_OFFSET                 (8u)
#define CapSense_CAPTEUR_PTR2SNS_RAM_SIZE                   (4u)
#define CapSense_CAPTEUR_PTR2SNS_RAM_PARAM_ID               (0xD3000008u)

#define CapSense_CAPTEUR_PTR2FLTR_HISTORY_VALUE             (CapSense_dsFlash.wdgtArray[0].ptr2FltrHistory)
#define CapSense_CAPTEUR_PTR2FLTR_HISTORY_OFFSET            (12u)
#define CapSense_CAPTEUR_PTR2FLTR_HISTORY_SIZE              (4u)
#define CapSense_CAPTEUR_PTR2FLTR_HISTORY_PARAM_ID          (0xD200000Cu)

#define CapSense_CAPTEUR_PTR2DEBOUNCE_VALUE                 (CapSense_dsFlash.wdgtArray[0].ptr2DebounceArr)
#define CapSense_CAPTEUR_PTR2DEBOUNCE_OFFSET                (16u)
#define CapSense_CAPTEUR_PTR2DEBOUNCE_SIZE                  (4u)
#define CapSense_CAPTEUR_PTR2DEBOUNCE_PARAM_ID              (0xD4000010u)

#define CapSense_CAPTEUR_STATIC_CONFIG_VALUE                (CapSense_dsFlash.wdgtArray[0].staticConfig)
#define CapSense_CAPTEUR_STATIC_CONFIG_OFFSET               (20u)
#define CapSense_CAPTEUR_STATIC_CONFIG_SIZE                 (4u)
#define CapSense_CAPTEUR_STATIC_CONFIG_PARAM_ID             (0xD5000014u)

#define CapSense_CAPTEUR_TOTAL_NUM_SNS_VALUE                (CapSense_dsFlash.wdgtArray[0].totalNumSns)
#define CapSense_CAPTEUR_TOTAL_NUM_SNS_OFFSET               (24u)
#define CapSense_CAPTEUR_TOTAL_NUM_SNS_SIZE                 (2u)
#define CapSense_CAPTEUR_TOTAL_NUM_SNS_PARAM_ID             (0x99000018u)

#define CapSense_CAPTEUR_TYPE_VALUE                         (CapSense_dsFlash.wdgtArray[0].wdgtType)
#define CapSense_CAPTEUR_TYPE_OFFSET                        (26u)
#define CapSense_CAPTEUR_TYPE_SIZE                          (1u)
#define CapSense_CAPTEUR_TYPE_PARAM_ID                      (0x5D00001Au)

#define CapSense_CAPTEUR_NUM_COLS_VALUE                     (CapSense_dsFlash.wdgtArray[0].numCols)
#define CapSense_CAPTEUR_NUM_COLS_OFFSET                    (27u)
#define CapSense_CAPTEUR_NUM_COLS_SIZE                      (1u)
#define CapSense_CAPTEUR_NUM_COLS_PARAM_ID                  (0x5B00001Bu)

#define CapSense_CAPTEUR_PTR2SNS_CP_VALUE                   (CapSense_dsFlash.wdgtArray[0].ptr2SnsCpArr)
#define CapSense_CAPTEUR_PTR2SNS_CP_OFFSET                  (28u)
#define CapSense_CAPTEUR_PTR2SNS_CP_SIZE                    (4u)
#define CapSense_CAPTEUR_PTR2SNS_CP_PARAM_ID                (0xD700001Cu)


#endif /* End CY_SENSE_CapSense_REGISTER_MAP_H */


/* [] END OF FILE */
