/***************************************************************************//**
* \file TX_BOOT.h
* \version 4.0
*
* \brief
*  This file provides constants and parameter values of the bootloader
*  communication APIs for the SCB Component.
*
* Note:
*
********************************************************************************
* \copyright
* Copyright 2014-2017, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_BOOT_TX_H)
#define CY_SCB_BOOT_TX_H

#include "TX_PVT.h"

#if (TX_SCB_MODE_I2C_INC)
    #include "TX_I2C.h"
#endif /* (TX_SCB_MODE_I2C_INC) */

#if (TX_SCB_MODE_EZI2C_INC)
    #include "TX_EZI2C.h"
#endif /* (TX_SCB_MODE_EZI2C_INC) */

#if (TX_SCB_MODE_SPI_INC || TX_SCB_MODE_UART_INC)
    #include "TX_SPI_UART.h"
#endif /* (TX_SCB_MODE_SPI_INC || TX_SCB_MODE_UART_INC) */


/***************************************
*  Conditional Compilation Parameters
****************************************/

/* Bootloader communication interface enable */
#define TX_BTLDR_COMM_ENABLED ((CYDEV_BOOTLOADER_IO_COMP == CyBtldr_TX) || \
                                             (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface))

/* Enable I2C bootloader communication */
#if (TX_SCB_MODE_I2C_INC)
    #define TX_I2C_BTLDR_COMM_ENABLED     (TX_BTLDR_COMM_ENABLED && \
                                                            (TX_SCB_MODE_UNCONFIG_CONST_CFG || \
                                                             TX_I2C_SLAVE_CONST))
#else
     #define TX_I2C_BTLDR_COMM_ENABLED    (0u)
#endif /* (TX_SCB_MODE_I2C_INC) */

/* EZI2C does not support bootloader communication. Provide empty APIs */
#if (TX_SCB_MODE_EZI2C_INC)
    #define TX_EZI2C_BTLDR_COMM_ENABLED   (TX_BTLDR_COMM_ENABLED && \
                                                         TX_SCB_MODE_UNCONFIG_CONST_CFG)
#else
    #define TX_EZI2C_BTLDR_COMM_ENABLED   (0u)
#endif /* (TX_EZI2C_BTLDR_COMM_ENABLED) */

/* Enable SPI bootloader communication */
#if (TX_SCB_MODE_SPI_INC)
    #define TX_SPI_BTLDR_COMM_ENABLED     (TX_BTLDR_COMM_ENABLED && \
                                                            (TX_SCB_MODE_UNCONFIG_CONST_CFG || \
                                                             TX_SPI_SLAVE_CONST))
#else
        #define TX_SPI_BTLDR_COMM_ENABLED (0u)
#endif /* (TX_SPI_BTLDR_COMM_ENABLED) */

/* Enable UART bootloader communication */
#if (TX_SCB_MODE_UART_INC)
       #define TX_UART_BTLDR_COMM_ENABLED    (TX_BTLDR_COMM_ENABLED && \
                                                            (TX_SCB_MODE_UNCONFIG_CONST_CFG || \
                                                             (TX_UART_RX_DIRECTION && \
                                                              TX_UART_TX_DIRECTION)))
#else
     #define TX_UART_BTLDR_COMM_ENABLED   (0u)
#endif /* (TX_UART_BTLDR_COMM_ENABLED) */

/* Enable bootloader communication */
#define TX_BTLDR_COMM_MODE_ENABLED    (TX_I2C_BTLDR_COMM_ENABLED   || \
                                                     TX_SPI_BTLDR_COMM_ENABLED   || \
                                                     TX_EZI2C_BTLDR_COMM_ENABLED || \
                                                     TX_UART_BTLDR_COMM_ENABLED)


/***************************************
*        Function Prototypes
***************************************/

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (TX_I2C_BTLDR_COMM_ENABLED)
    /* I2C Bootloader physical layer functions */
    void TX_I2CCyBtldrCommStart(void);
    void TX_I2CCyBtldrCommStop (void);
    void TX_I2CCyBtldrCommReset(void);
    cystatus TX_I2CCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus TX_I2CCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map I2C specific bootloader communication APIs to SCB specific APIs */
    #if (TX_SCB_MODE_I2C_CONST_CFG)
        #define TX_CyBtldrCommStart   TX_I2CCyBtldrCommStart
        #define TX_CyBtldrCommStop    TX_I2CCyBtldrCommStop
        #define TX_CyBtldrCommReset   TX_I2CCyBtldrCommReset
        #define TX_CyBtldrCommRead    TX_I2CCyBtldrCommRead
        #define TX_CyBtldrCommWrite   TX_I2CCyBtldrCommWrite
    #endif /* (TX_SCB_MODE_I2C_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (TX_I2C_BTLDR_COMM_ENABLED) */


#if defined(CYDEV_BOOTLOADER_IO_COMP) && (TX_EZI2C_BTLDR_COMM_ENABLED)
    /* Bootloader physical layer functions */
    void TX_EzI2CCyBtldrCommStart(void);
    void TX_EzI2CCyBtldrCommStop (void);
    void TX_EzI2CCyBtldrCommReset(void);
    cystatus TX_EzI2CCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus TX_EzI2CCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map EZI2C specific bootloader communication APIs to SCB specific APIs */
    #if (TX_SCB_MODE_EZI2C_CONST_CFG)
        #define TX_CyBtldrCommStart   TX_EzI2CCyBtldrCommStart
        #define TX_CyBtldrCommStop    TX_EzI2CCyBtldrCommStop
        #define TX_CyBtldrCommReset   TX_EzI2CCyBtldrCommReset
        #define TX_CyBtldrCommRead    TX_EzI2CCyBtldrCommRead
        #define TX_CyBtldrCommWrite   TX_EzI2CCyBtldrCommWrite
    #endif /* (TX_SCB_MODE_EZI2C_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (TX_EZI2C_BTLDR_COMM_ENABLED) */

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (TX_SPI_BTLDR_COMM_ENABLED)
    /* SPI Bootloader physical layer functions */
    void TX_SpiCyBtldrCommStart(void);
    void TX_SpiCyBtldrCommStop (void);
    void TX_SpiCyBtldrCommReset(void);
    cystatus TX_SpiCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus TX_SpiCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map SPI specific bootloader communication APIs to SCB specific APIs */
    #if (TX_SCB_MODE_SPI_CONST_CFG)
        #define TX_CyBtldrCommStart   TX_SpiCyBtldrCommStart
        #define TX_CyBtldrCommStop    TX_SpiCyBtldrCommStop
        #define TX_CyBtldrCommReset   TX_SpiCyBtldrCommReset
        #define TX_CyBtldrCommRead    TX_SpiCyBtldrCommRead
        #define TX_CyBtldrCommWrite   TX_SpiCyBtldrCommWrite
    #endif /* (TX_SCB_MODE_SPI_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (TX_SPI_BTLDR_COMM_ENABLED) */

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (TX_UART_BTLDR_COMM_ENABLED)
    /* UART Bootloader physical layer functions */
    void TX_UartCyBtldrCommStart(void);
    void TX_UartCyBtldrCommStop (void);
    void TX_UartCyBtldrCommReset(void);
    cystatus TX_UartCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus TX_UartCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Map UART specific bootloader communication APIs to SCB specific APIs */
    #if (TX_SCB_MODE_UART_CONST_CFG)
        #define TX_CyBtldrCommStart   TX_UartCyBtldrCommStart
        #define TX_CyBtldrCommStop    TX_UartCyBtldrCommStop
        #define TX_CyBtldrCommReset   TX_UartCyBtldrCommReset
        #define TX_CyBtldrCommRead    TX_UartCyBtldrCommRead
        #define TX_CyBtldrCommWrite   TX_UartCyBtldrCommWrite
    #endif /* (TX_SCB_MODE_UART_CONST_CFG) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (TX_UART_BTLDR_COMM_ENABLED) */

/**
* \addtogroup group_bootloader
* @{
*/

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (TX_BTLDR_COMM_ENABLED)
    #if (TX_SCB_MODE_UNCONFIG_CONST_CFG)
        /* Bootloader physical layer functions */
        void TX_CyBtldrCommStart(void);
        void TX_CyBtldrCommStop (void);
        void TX_CyBtldrCommReset(void);
        cystatus TX_CyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
        cystatus TX_CyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    #endif /* (TX_SCB_MODE_UNCONFIG_CONST_CFG) */

    /* Map SCB specific bootloader communication APIs to common APIs */
    #if (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_TX)
        #define CyBtldrCommStart    TX_CyBtldrCommStart
        #define CyBtldrCommStop     TX_CyBtldrCommStop
        #define CyBtldrCommReset    TX_CyBtldrCommReset
        #define CyBtldrCommWrite    TX_CyBtldrCommWrite
        #define CyBtldrCommRead     TX_CyBtldrCommRead
    #endif /* (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_TX) */

#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (TX_BTLDR_COMM_ENABLED) */

/** @} group_bootloader */

/***************************************
*           API Constants
***************************************/

/* Timeout unit in milliseconds */
#define TX_WAIT_1_MS  (1u)

/* Return number of bytes to copy into bootloader buffer */
#define TX_BYTES_TO_COPY(actBufSize, bufSize) \
                            ( ((uint32)(actBufSize) < (uint32)(bufSize)) ? \
                                ((uint32) (actBufSize)) : ((uint32) (bufSize)) )

/* Size of Read/Write buffers for I2C bootloader  */
#define TX_I2C_BTLDR_SIZEOF_READ_BUFFER   (64u)
#define TX_I2C_BTLDR_SIZEOF_WRITE_BUFFER  (64u)

/* Byte to byte time interval: calculated basing on current component
* data rate configuration, can be defined in project if required.
*/
#ifndef TX_SPI_BYTE_TO_BYTE
    #define TX_SPI_BYTE_TO_BYTE   (160u)
#endif

/* Byte to byte time interval: calculated basing on current component
* baud rate configuration, can be defined in the project if required.
*/
#ifndef TX_UART_BYTE_TO_BYTE
    #define TX_UART_BYTE_TO_BYTE  (2500u)
#endif /* TX_UART_BYTE_TO_BYTE */

#endif /* (CY_SCB_BOOT_TX_H) */


/* [] END OF FILE */
