/***************************************************************************//**
* \file .h
* \version 4.0
*
* \brief
*  This private file provides constants and parameter values for the
*  SCB Component in I2C mode.
*  Please do not use this file or its content in your project.
*
* Note:
*
********************************************************************************
* \copyright
* Copyright 2013-2017, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_I2C_PVT_TX_H)
#define CY_SCB_I2C_PVT_TX_H

#include "TX_I2C.h"


/***************************************
*     Private Global Vars
***************************************/

extern volatile uint8 TX_state; /* Current state of I2C FSM */

#if(TX_I2C_SLAVE_CONST)
    extern volatile uint8 TX_slStatus;          /* Slave Status */

    /* Receive buffer variables */
    extern volatile uint8 * TX_slWrBufPtr;      /* Pointer to Receive buffer  */
    extern volatile uint32  TX_slWrBufSize;     /* Slave Receive buffer size  */
    extern volatile uint32  TX_slWrBufIndex;    /* Slave Receive buffer Index */

    /* Transmit buffer variables */
    extern volatile uint8 * TX_slRdBufPtr;      /* Pointer to Transmit buffer  */
    extern volatile uint32  TX_slRdBufSize;     /* Slave Transmit buffer size  */
    extern volatile uint32  TX_slRdBufIndex;    /* Slave Transmit buffer Index */
    extern volatile uint32  TX_slRdBufIndexTmp; /* Slave Transmit buffer Index Tmp */
    extern volatile uint8   TX_slOverFlowCount; /* Slave Transmit Overflow counter */
#endif /* (TX_I2C_SLAVE_CONST) */

#if(TX_I2C_MASTER_CONST)
    extern volatile uint16 TX_mstrStatus;      /* Master Status byte  */
    extern volatile uint8  TX_mstrControl;     /* Master Control byte */

    /* Receive buffer variables */
    extern volatile uint8 * TX_mstrRdBufPtr;   /* Pointer to Master Read buffer */
    extern volatile uint32  TX_mstrRdBufSize;  /* Master Read buffer size       */
    extern volatile uint32  TX_mstrRdBufIndex; /* Master Read buffer Index      */

    /* Transmit buffer variables */
    extern volatile uint8 * TX_mstrWrBufPtr;   /* Pointer to Master Write buffer */
    extern volatile uint32  TX_mstrWrBufSize;  /* Master Write buffer size       */
    extern volatile uint32  TX_mstrWrBufIndex; /* Master Write buffer Index      */
    extern volatile uint32  TX_mstrWrBufIndexTmp; /* Master Write buffer Index Tmp */
#endif /* (TX_I2C_MASTER_CONST) */

#if (TX_I2C_CUSTOM_ADDRESS_HANDLER_CONST)
    extern uint32 (*TX_customAddressHandler) (void);
#endif /* (TX_I2C_CUSTOM_ADDRESS_HANDLER_CONST) */

/***************************************
*     Private Function Prototypes
***************************************/

#if(TX_SCB_MODE_I2C_CONST_CFG)
    void TX_I2CInit(void);
#endif /* (TX_SCB_MODE_I2C_CONST_CFG) */

void TX_I2CStop(void);
void TX_I2CFwBlockReset(void);

void TX_I2CSaveConfig(void);
void TX_I2CRestoreConfig(void);

#if(TX_I2C_MASTER_CONST)
    void TX_I2CReStartGeneration(void);
#endif /* (TX_I2C_MASTER_CONST) */

#endif /* (CY_SCB_I2C_PVT_TX_H) */


/* [] END OF FILE */
