/*******************************************************************************
* File Name: TX_SCBCLK.h
* Version 2.20
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_TX_SCBCLK_H)
#define CY_CLOCK_TX_SCBCLK_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
*        Function Prototypes
***************************************/
#if defined CYREG_PERI_DIV_CMD

void TX_SCBCLK_StartEx(uint32 alignClkDiv);
#define TX_SCBCLK_Start() \
    TX_SCBCLK_StartEx(TX_SCBCLK__PA_DIV_ID)

#else

void TX_SCBCLK_Start(void);

#endif/* CYREG_PERI_DIV_CMD */

void TX_SCBCLK_Stop(void);

void TX_SCBCLK_SetFractionalDividerRegister(uint16 clkDivider, uint8 clkFractional);

uint16 TX_SCBCLK_GetDividerRegister(void);
uint8  TX_SCBCLK_GetFractionalDividerRegister(void);

#define TX_SCBCLK_Enable()                         TX_SCBCLK_Start()
#define TX_SCBCLK_Disable()                        TX_SCBCLK_Stop()
#define TX_SCBCLK_SetDividerRegister(clkDivider, reset)  \
    TX_SCBCLK_SetFractionalDividerRegister((clkDivider), 0u)
#define TX_SCBCLK_SetDivider(clkDivider)           TX_SCBCLK_SetDividerRegister((clkDivider), 1u)
#define TX_SCBCLK_SetDividerValue(clkDivider)      TX_SCBCLK_SetDividerRegister((clkDivider) - 1u, 1u)


/***************************************
*             Registers
***************************************/
#if defined CYREG_PERI_DIV_CMD

#define TX_SCBCLK_DIV_ID     TX_SCBCLK__DIV_ID

#define TX_SCBCLK_CMD_REG    (*(reg32 *)CYREG_PERI_DIV_CMD)
#define TX_SCBCLK_CTRL_REG   (*(reg32 *)TX_SCBCLK__CTRL_REGISTER)
#define TX_SCBCLK_DIV_REG    (*(reg32 *)TX_SCBCLK__DIV_REGISTER)

#define TX_SCBCLK_CMD_DIV_SHIFT          (0u)
#define TX_SCBCLK_CMD_PA_DIV_SHIFT       (8u)
#define TX_SCBCLK_CMD_DISABLE_SHIFT      (30u)
#define TX_SCBCLK_CMD_ENABLE_SHIFT       (31u)

#define TX_SCBCLK_CMD_DISABLE_MASK       ((uint32)((uint32)1u << TX_SCBCLK_CMD_DISABLE_SHIFT))
#define TX_SCBCLK_CMD_ENABLE_MASK        ((uint32)((uint32)1u << TX_SCBCLK_CMD_ENABLE_SHIFT))

#define TX_SCBCLK_DIV_FRAC_MASK  (0x000000F8u)
#define TX_SCBCLK_DIV_FRAC_SHIFT (3u)
#define TX_SCBCLK_DIV_INT_MASK   (0xFFFFFF00u)
#define TX_SCBCLK_DIV_INT_SHIFT  (8u)

#else 

#define TX_SCBCLK_DIV_REG        (*(reg32 *)TX_SCBCLK__REGISTER)
#define TX_SCBCLK_ENABLE_REG     TX_SCBCLK_DIV_REG
#define TX_SCBCLK_DIV_FRAC_MASK  TX_SCBCLK__FRAC_MASK
#define TX_SCBCLK_DIV_FRAC_SHIFT (16u)
#define TX_SCBCLK_DIV_INT_MASK   TX_SCBCLK__DIVIDER_MASK
#define TX_SCBCLK_DIV_INT_SHIFT  (0u)

#endif/* CYREG_PERI_DIV_CMD */

#endif /* !defined(CY_CLOCK_TX_SCBCLK_H) */

/* [] END OF FILE */
